/*
 * @(#)Charge.java		1.10 07/01/20
 *
 * ChargedFluid package
 *
 * COPYRIGHT NOTICE
 * Copyright (c) 2007 Herbert H.H. Chang, Daniel J. Valentino, Gary R. Duckwiler, and Arthur W. Toga
 * Laboratory of Neuro Imaging, Department of Neurology, UCLA.
 */
 
package tools;

import java.awt.Point;
import java.awt.geom.Point2D;

/**
 * The <code>Charge</code> class is the basic element of the <code>ChargedFluid</code>.
 * It contains the position, charge, and electric fields that are used for the
 * evolution computation at each step. The charge dies after each step and new charges
 * are created via the front computation technique.
 */
public class Charge
{
	/**
	 * The charge position.
	 */
	public Point position;
	
	/** 
	 * The position of the charge in double. 
	 */
    public Point2D.Double pointDouble;
	
	/** 
	 * The charge quantity of this charge.
	 */
	public double charge;
	
	/** 
	 * Electric potential.
	 */
  	public double electricPotential;
  	
  	/** 
  	 * Electric field in X-axis. 
  	 */
  	public double electricFieldInX;

  	/** 
  	 * Electric field in Y-axis. 
  	 */
  	public double electricFieldInY;
	
	/** 
  	 * Electric magnitude. 
  	 */
  	public double electricMagnitude;
	
	/** 
	 * Effective field in X-axis. 
	 */
  	public double effectiveFieldInX;

  	/** 
  	 * Effective field in Y-axis. 
  	 */
  	public double effectiveFieldInY;
  	
	/** 
	 * True if the electric field direction is reversed. 
	 */
	public boolean isElectricDirectionInverse;
	
	/** 
	 * True if the effective field direction is reversed. 
	 */
	public boolean isEffectiveDirectionInverse;
	
	
	/** 
	 * Constructs a charge with the specified charge and position.
	 * @param	charge		the electric charge of the charge.
	 * @param	position	the position of the charge.
	 */
  	public Charge(double charge, Point position)
  	{
    	this.charge = charge;
    	this.position = position;
  	}
}